@@ -58,6 +58,7 @@ using GNU_gama::local::Xdiff;
 using GNU_gama::local::Ydiff;
 using GNU_gama::local::Zdiff;
 using GNU_gama::local::Azimuth;
+using GNU_gama::local::Coordinates;
 
 namespace
 {
@@ -99,7 +100,10 @@ public:
 
     void visit(Distance* obs)
     {
-      out << "<" << (tag="distance") << ">";
+      out << "<" << (tag="distance");// << ">";;
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -110,7 +114,10 @@ public:
     }
     void visit(Direction* obs)
     {
-      out << "<" << (tag="direction") << ">";
+      out << "<" << (tag="direction");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(angular);
       double m = R2G*(obs->value());
       *ostr << " <obs>" << m << "</obs>";
@@ -123,7 +130,10 @@ public:
     }
     void visit(Angle* obs)
     {
-      out << "<" << (tag="angle") << ">";
+      out << "<" << (tag="angle");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(angular);
       double m = R2G*(obs->value());
       *ostr << " <obs>" << m << "</obs>";
@@ -138,7 +148,10 @@ public:
     }
     void visit(H_Diff* obs)
     {
-      out << "<" << (tag="height-diff") << ">";
+      out << "<" << (tag="height-diff");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m =obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -149,7 +162,10 @@ public:
     }
     void visit(S_Distance* obs)
     {
-      out << "<" << (tag="slope-distance") << ">";
+      out << "<" << (tag="slope-distance");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -160,7 +176,10 @@ public:
     }
     void visit(Z_Angle* obs)
     {
-      out << "<" << (tag="zenith-angle") << ">";
+      out << "<" << (tag="zenith-angle");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(angular);
       double m = R2G*(obs->value());
       *ostr << " <obs>" << m << "</obs>";
@@ -171,7 +190,11 @@ public:
     }
     void visit(X* obs)
     {
-      out << "<" << (tag="coordinate-x") << ">";
+      out << "<" << (tag="coordinate-x");// << ">";
+      auto c = static_cast<const Coordinates*>(obs->ptr_cluster());
+      string s = c->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -182,7 +205,11 @@ public:
     }
     void visit(Y* obs)
     {
-      out << "<" << (tag="coordinate-y") << ">";
+      out << "<" << (tag="coordinate-y");// << ">";
+      auto c = static_cast<const Coordinates*>(obs->ptr_cluster());
+      string s = c->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << y_sign*m << "</obs>";
@@ -193,7 +220,11 @@ public:
     }
     void visit(Z* obs)
     {
-      out << "<" << (tag="coordinate-z") << ">";
+      out << "<" << (tag="coordinate-z");// << ">";
+      auto c = static_cast<const Coordinates*>(obs->ptr_cluster());
+      string s = c->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -204,7 +235,10 @@ public:
     }
     void visit(Xdiff* obs)
     {
-      out << "<" << (tag="dx") << ">";
+      out << "<" << (tag="dx");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -215,7 +249,10 @@ public:
     }
     void visit(Ydiff* obs)
     {
-      out << "<" << (tag="dy") << ">";
+      out << "<" << (tag="dy");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << y_sign*m << "</obs>";
@@ -226,7 +263,10 @@ public:
     }
     void visit(Zdiff* obs)
     {
-      out << "<" << (tag="dz") << ">";
+      out << "<" << (tag="dz");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(linear);
       double m = obs->value();
       *ostr << " <obs>" << m << "</obs>";
@@ -237,7 +277,10 @@ public:
     }
     void visit(Azimuth* obs)
     {
-      out << "<" << (tag="azimuth") << ">";
+      out << "<" << (tag="azimuth");// << ">";
+      string s = obs->get_extern();
+      if (!s.empty()) out << " extern=\"" << s << "\"";
+      out << ">";
       ostr->precision(angular);
       double m = R2G*(obs->value());
       *ostr << " <obs>" << m << "</obs>";
@@ -417,8 +460,8 @@ void LocalNetworkXML::observations_summary(std::ostream& out) const
       void visit(S_Distance*) { chords++; }
       void visit(Z_Angle*)    { zangles++; }
       void visit(X*)          { coords++; }
-      void visit(Y*)          { }
-      void visit(Z*)          { }
+      void visit(Y*)          { coords++; }
+      void visit(Z*)          { coords++; }
       void visit(Xdiff*)      { vectors++; }
       void visit(Ydiff*)      { }
       void visit(Zdiff*)      { }
